## 0.2.1
[PATCH] Fix required version of pymodbus to 3.9.2 (due to breaking changes in 3.10)

### 0.2.0

[MINOR] Signals and SignalsEngine are no longer "Singleton".

Additionally, fixed import error for "FramerType". 

### 0.1.0

[MINOR] Initial release.